@@ -12,12 +12,10 @@
 #include "nma-cert-chooser-button.h"
 #include "utils.h"
 
-#if GTK_CHECK_VERSION(4,0,0) ? WITH_GCR_GTK4 : WITH_GCR_GTK3
+#if WITH_GCR
 #include "nma-pkcs11-cert-chooser-dialog.h"
 #include <gck/gck.h>
-/* GCK version numbers are funny: version 3 is older than version 1.9x.
- * See: https://gitlab.gnome.org/GNOME/gcr/-/merge_requests/109 */
-#if !GCK_CHECK_VERSION(1,90,0) || (GCK_MAJOR_VERSION == 3 && GCK_MINOR_VERSION < 90)
+#if !GCK_CHECK_VERSION(3,90,0)
 #define gck_uri_data_parse gck_uri_parse
 #endif
 #endif
@@ -69,7 +67,7 @@ enum {
 static void
 update_title (NMACertChooserButton *button);
 
-#if GTK_CHECK_VERSION(4,0,0) ? WITH_GCR_GTK4 : WITH_GCR_GTK3
+#if WITH_GCR
 static gboolean
 is_this_a_slot_nobody_loves (GckSlot *slot)
 {
@@ -362,7 +360,7 @@ changed (GtkComboBox *combo_box, gpointer user_data)
 	gchar *label;
 	GckSlot *slot;
 
-	if (gtk_combo_box_get_active (combo_box) == -1)
+	if (gtk_combo_box_get_active (combo_box) == 0)
 		return;
 
 	gtk_combo_box_popdown (combo_box);
@@ -380,7 +378,7 @@ changed (GtkComboBox *combo_box, gpointer user_data)
 
 	g_free (label);
 	g_clear_object (&slot);
-	gtk_combo_box_set_active (combo_box, -1);
+	gtk_combo_box_set_active (combo_box, 0);
 }
 
 static gboolean
