@@ -439,12 +439,12 @@ iso_3166_parser_start_element (GMarkupParseContext *context,
 				name = attribute_values[i];
 		}
 		if (!country_code) {
-			g_warning ("%s: missing mandatory 'alpha_2_code' atribute in '%s'"
+			g_warning ("%s: missing mandatory 'alpha_2_code' attribute in '%s'"
 			           " element.", __func__, element_name);
 			return;
 		}
 		if (!name) {
-			g_warning ("%s: missing mandatory 'name' atribute in '%s'"
+			g_warning ("%s: missing mandatory 'name' attribute in '%s'"
 			           " element.", __func__, element_name);
 			return;
 		}
@@ -465,8 +465,9 @@ static const GMarkupParser iso_3166_parser = {
 };
 
 static gboolean
-read_country_codes (GHashTable *table,
+_read_country_codes (GHashTable *table,
                     const gchar *country_codes_file,
+                    const gchar *country_codes_locale,
                     GCancellable *cancellable,
                     GError **error)
 {
@@ -474,10 +475,6 @@ read_country_codes (GHashTable *table,
 	char *buf;
 	gsize buf_len;
 
-	/* Set domain to iso_3166 for country name translation */
-	bindtextdomain ("iso_3166", ISO_CODES_PREFIX "/locale");
-	bind_textdomain_codeset ("iso_3166", "UTF-8");
-
 	if (!g_file_get_contents (country_codes_file, &buf, &buf_len, error)) {
 		g_prefix_error (error,
 		                "Failed to load '%s' from 'iso-codes': ",
@@ -493,11 +490,41 @@ read_country_codes (GHashTable *table,
 		return FALSE;
 	}
 
+	/* Set domain to iso_3166 for country name translation */
+	bindtextdomain ("iso_3166", country_codes_locale);
+	bind_textdomain_codeset ("iso_3166", "UTF-8");
+
 	g_markup_parse_context_free (ctx);
 	g_free (buf);
 	return TRUE;
 }
 
+static gboolean
+read_country_codes_file (GHashTable *table,
+                         const gchar *country_codes_file,
+                         GCancellable *cancellable,
+                         GError **error)
+{
+	gs_free char *country_codes_locale = NULL;
+
+	country_codes_locale = g_build_filename (country_codes_file, "../../locale", NULL);
+	return _read_country_codes (table, country_codes_file, country_codes_locale, cancellable, error);
+}
+
+static gboolean
+read_country_codes_dir (GHashTable *table,
+                        const gchar *country_codes_dir,
+                        GCancellable *cancellable,
+                        GError **error)
+{
+	gs_free char *country_codes_file = NULL;
+	gs_free char *country_codes_locale = NULL;
+
+	country_codes_file = g_build_filename (country_codes_dir, ISO_3166_COUNTRY_CODES, NULL);
+	country_codes_locale = g_build_filename (country_codes_dir, "locale", NULL);
+	return _read_country_codes (table, country_codes_file, country_codes_locale, cancellable, error);
+}
+
 /******************************************************************************/
 /* XML Parser for serviceproviders.xml */
 
@@ -523,20 +550,6 @@ typedef struct {
 	MobileContextState state;
 } MobileParser;
 
-static NMACountryInfo *
-lookup_country (GHashTable *table, const char *country_code)
-{
-	NMACountryInfo *country_info;
-
-	country_info = g_hash_table_lookup (table, country_code);
-	if (!country_info) {
-		g_warning ("%s: adding providers for unknown country '%s'", __func__, country_code);
-		country_info = g_hash_table_lookup (table, "");
-	}
-
-	return country_info;
-}
-
 static void
 parser_toplevel_start (MobileParser *parser,
                        const char *name,
@@ -561,7 +574,7 @@ parser_toplevel_start (MobileParser *parser,
 			if (!strcmp (attribute_names[i], "code")) {
 				g_free (parser->country_code);
 				parser->country_code = g_ascii_strup (attribute_values[i], -1);
-				parser->current_country = lookup_country (parser->table, parser->country_code);
+				parser->current_country = g_hash_table_lookup (parser->table, parser->country_code);
 				parser->state = PARSER_COUNTRY;
 				break;
 			}
@@ -611,7 +624,7 @@ parser_gsm_start (MobileParser *parser,
 			else if (!strcmp (attribute_names[i], "mnc"))
 				mnc = attribute_values[i];
 
-			if (mcc && strlen (mcc) && mnc && strlen (mnc)) {
+			if (mcc && *mcc && mnc && *mnc) {
 				gchar *mccmnc;
 
 				if (!parser->current_provider->mcc_mnc)
@@ -703,7 +716,17 @@ static void
 parser_country_end (MobileParser *parser,
                     const char *name)
 {
-	if (!strcmp (name, "country")) {
+	if (!strcmp (name, "name")) {
+		if (!parser->current_country) {
+			g_debug ("%s: code '%s' unknown, falling back to '%s'", __func__,
+				 parser->country_code, parser->text_buffer);
+			parser->current_country = country_info_new (parser->country_code,
+								    parser->text_buffer);
+			g_hash_table_insert (parser->table,
+					     g_strdup (parser->country_code),
+					     parser->current_country);
+		}
+	} else if (!strcmp (name, "country")) {
 		parser->current_country = NULL;
 		g_free (parser->country_code);
 		parser->country_code = NULL;
@@ -717,6 +740,14 @@ static void
 parser_provider_end (MobileParser *parser,
                      const char *name)
 {
+	if (!parser->current_country) {
+		if (g_hash_table_size (parser->table) > 1) {
+			g_warning ("%s: adding providers for unknown country '%s'",
+			           __func__, parser->country_code);
+		}
+		parser->current_country = g_hash_table_lookup (parser->table, "");
+	}
+
 	if (!strcmp (name, "name")) {
 		if (!parser->current_provider->name) {
 			/* Use the first one. */
@@ -964,7 +995,7 @@ mobile_providers_parse_sync (const gchar *country_codes,
 	char *path;
 	const gchar * const *dirs;
 	int i;
-	gboolean success;
+	gboolean success = FALSE;
 
 	dirs = g_get_system_data_dirs ();
 	countries = g_hash_table_new_full (g_str_hash,
@@ -977,28 +1008,20 @@ mobile_providers_parse_sync (const gchar *country_codes,
 
 	/* Use default paths if none given */
 	if (country_codes) {
-		if (!read_country_codes (countries, country_codes, cancellable, error)) {
+		if (!read_country_codes_file (countries, country_codes, cancellable, error)) {
 			g_hash_table_unref (countries);
 			return FALSE;
 		}
 	} else {
 		/* First try the user override file. */
-		path = g_build_filename (g_get_user_data_dir (), ISO_3166_COUNTRY_CODES, NULL);
-		success = read_country_codes (countries, path, cancellable, NULL);
-		g_free (path);
+		success = read_country_codes_dir (countries, g_get_user_data_dir (), cancellable, NULL);
 
 		/* Look in system locations. */
-		for (i = 0; dirs[i] && !success; i++) {
-			path = g_build_filename (dirs[i], ISO_3166_COUNTRY_CODES, NULL);
-			success = read_country_codes (countries, path, cancellable, NULL);
-			g_free (path);
-		}
+		for (i = 0; dirs[i] && !success; i++)
+			success = read_country_codes_dir (countries, dirs[i], cancellable, NULL);
 
-		if (!success) {
-			path = g_build_filename (ISO_CODES_PREFIX, "share", ISO_3166_COUNTRY_CODES, NULL);
-			success = read_country_codes (countries, path, cancellable, NULL);
-			g_free (path);
-		}
+		if (!success)
+			success = read_country_codes_dir (countries, ISO_CODES_DATADIR, cancellable, NULL);
 
 		if (!success) {
 			g_warning ("Could not find the country codes file (%s): check your installation\n",
@@ -1006,6 +1029,22 @@ mobile_providers_parse_sync (const gchar *country_codes,
 		}
 	}
 
+	/*
+	 * The areas where mobile operators operate, the areas where ITU
+	 * recognizes the use of a MCC and ISO 3166-1 country codes
+	 * generally overlap very well, which allows use to use ISO 3166-1
+	 * codes to identify the area in the mobile-broadband-database.
+	 *
+	 * Kosovo seems to be an exception. There are operators specific
+	 * to the area, use a Kosovo-specific MCC, but there's no
+	 * ISO 3166-1 code. Until it gets one, let's use a provisional one
+	 * that seems to be in common use.
+	 */
+	if (success) {
+		g_hash_table_insert (countries, g_strdup ("XK"),
+				     country_info_new ("XK", _("Kosovo")));
+	}
+
 	if (service_providers) {
 		if (!read_service_providers (countries, service_providers, cancellable, error)) {
 			g_hash_table_unref (countries);
