@@ -13,6 +13,10 @@ G_BEGIN_DECLS
 typedef struct _NMAWs8021x NMAWs8021x;
 typedef struct _NMAWs8021xClass NMAWs8021xClass;
 
+#if defined(G_DEFINE_AUTOPTR_CLEANUP_FUNC) && NMA_VERSION_MIN_REQUIRED >= NMA_VERSION_1_10_6
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(NMAWs8021x, g_object_unref)
+#endif
+
 #define NMA_TYPE_WS_802_1X            (nma_ws_802_1x_get_type ())
 #define NMA_WS_802_1X(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NMA_TYPE_WS_802_1X, NMAWs8021x))
 #define NMA_WS_802_1X_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), NMA_TYPE_WS_802_1X, NMAWs8021xClass))
