@@ -15,6 +15,10 @@ G_BEGIN_DECLS
 typedef struct _NMAWsWepKey NMAWsWepKey;
 typedef struct _NMAWsWepKeyClass NMAWsWepKeyClass;
 
+#if defined(G_DEFINE_AUTOPTR_CLEANUP_FUNC) && NMA_VERSION_MIN_REQUIRED >= NMA_VERSION_1_10_6
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(NMAWsWepKey, g_object_unref)
+#endif
+
 #define NMA_TYPE_WS_WEP_KEY            (nma_ws_wep_key_get_type ())
 #define NMA_WS_WEP_KEY(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NMA_TYPE_WS_WEP_KEY, NMAWsWepKey))
 #define NMA_WS_WEP_KEY_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), NMA_TYPE_WS_WEP_KEY, NMAWsWepKeyClass))
